double  CFUNC_pdi ( unsigned char *, int, int );
void    CFUNC_pdo ( unsigned char *, double, int, int );
void    CFUNC_fcs_xlate ( unsigned char *, unsigned char *,
    int, unsigned char * );
